@@ -4,7 +4,7 @@ use crate::{
     context::{calculate_after_context, calculate_before_context, opposite_positions},
     hunks::Hunk,
     lines::{format_line_num, MaxLine},
-    style::apply_colors,
+    style::{self, apply_colors, BackgroundColor},
     syntax::MatchedPos,
 };
 use colored::*;
@@ -15,9 +15,12 @@ pub fn display(
     lhs_positions: &[MatchedPos],
     rhs_positions: &[MatchedPos],
     hunks: &[Hunk],
+    display_path: &str,
+    lang_name: &str,
+    background: BackgroundColor,
 ) -> String {
-    let lhs_colored = apply_colors(lhs_src, true, lhs_positions);
-    let rhs_colored = apply_colors(rhs_src, false, rhs_positions);
+    let lhs_colored = apply_colors(lhs_src, true, background, lhs_positions);
+    let rhs_colored = apply_colors(rhs_src, false, background, rhs_positions);
 
     let lhs_lines: Vec<_> = lhs_colored.lines().collect();
     let rhs_lines: Vec<_> = rhs_colored.lines().collect();
@@ -27,7 +30,16 @@ pub fn display(
     let opposite_to_lhs = opposite_positions(lhs_positions);
     let opposite_to_rhs = opposite_positions(rhs_positions);
 
-    for hunk in hunks {
+    for (i, hunk) in hunks.iter().enumerate() {
+        res.push_str(&style::header(
+            display_path,
+            i + 1,
+            hunks.len(),
+            lang_name,
+            background,
+        ));
+        res.push('\n');
+
         let hunk_lines = hunk.lines.clone();
 
         let before_lines =
@@ -54,7 +66,7 @@ pub fn display(
 
         for (lhs_line, _) in &hunk_lines {
             if let Some(lhs_line) = lhs_line {
-                res.push_str(&format_line_num(*lhs_line).bright_red().to_string());
+                res.push_str(&format_line_num(*lhs_line).red().bold().to_string());
                 res.push_str("   ");
                 res.push_str(lhs_lines[lhs_line.0]);
             } else {
@@ -65,7 +77,7 @@ pub fn display(
         for (_, rhs_line) in &hunk_lines {
             if let Some(rhs_line) = rhs_line {
                 res.push_str("   ");
-                res.push_str(&format_line_num(*rhs_line).bright_green().to_string());
+                res.push_str(&format_line_num(*rhs_line).green().bold().to_string());
                 res.push_str(rhs_lines[rhs_line.0]);
             } else {
                 continue;
