@@ -1,9 +1,10 @@
 //! Manipulate lines of text and groups of lines.
 
 use crate::positions::SingleLineSpan;
-use lazy_static::lazy_static;
-use regex::Regex;
-use std::{cmp::max, fmt};
+use std::{
+    cmp::{max, Ordering},
+    fmt,
+};
 
 /// A distinct number type for line numbers, to prevent confusion with
 /// other numerical data.
@@ -20,7 +21,11 @@ impl LineNumber {
 
 impl fmt::Debug for LineNumber {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        f.write_fmt(format_args!("LineNumber: {}", self.0))
+        f.write_fmt(format_args!(
+            "LineNumber: {} (raw: {})",
+            self.one_indexed(),
+            self.0
+        ))
     }
 }
 
@@ -46,48 +51,56 @@ struct LinePosition {
 /// line-relative positions.
 #[derive(Debug)]
 pub struct NewlinePositions {
-    /// A vector of the start positions of all the lines in `s`.
-    positions: Vec<usize>,
-    str_length: usize,
+    /// A vector of the start and end positions of all the lines in
+    /// `s`. Positions include the newline character itself.
+    positions: Vec<(usize, usize)>,
 }
 
 impl From<&str> for NewlinePositions {
     fn from(s: &str) -> Self {
-        lazy_static! {
-            static ref NEWLINE_RE: Regex = Regex::new("\n").unwrap();
+        let mut line_start = 0;
+        let mut positions = vec![];
+        for line in s.split('\n') {
+            let line_end = line_start + line.len() + "\n".len();
+            // TODO: this assumes lines terminate with \n, not \r\n.
+            positions.push((line_start, line_end - 1));
+            line_start = line_end;
         }
-        let mut positions: Vec<_> = NEWLINE_RE.find_iter(s).map(|mat| mat.end()).collect();
-        positions.insert(0, 0);
 
-        NewlinePositions {
-            positions,
-            str_length: s.len(),
-        }
+        NewlinePositions { positions }
     }
 }
 
 impl NewlinePositions {
+    fn from_offset(&self, offset: usize) -> usize {
+        let idx = self.positions.binary_search_by(|(line_start, line_end)| {
+            if *line_end < offset {
+                return Ordering::Less;
+            }
+            if *line_start > offset {
+                return Ordering::Greater;
+            }
+
+            Ordering::Equal
+        });
+
+        idx.expect("line should be present")
+    }
+
     /// Convert to single-line spans. If the original span crosses a
     /// newline, the vec will contain multiple items.
     pub fn from_offsets(&self, region_start: usize, region_end: usize) -> Vec<SingleLineSpan> {
+        assert!(region_start <= region_end);
+
+        let first_idx = self.from_offset(region_start);
+        let last_idx = self.from_offset(region_end);
+
         let mut res = vec![];
-        for (line_num, line_start) in self.positions.iter().enumerate() {
-            let line_end = match self.positions.get(line_num + 1) {
-                // TODO: this assumes lines terminate with \n, not \r\n.
-                Some(v) => *v - 1,
-                None => self.str_length,
-            };
-
-            if region_start > line_end {
-                continue;
-            }
-            if *line_start > region_end {
-                break;
-            }
-
+        for idx in first_idx..=last_idx {
+            let (line_start, line_end) = self.positions[idx];
             res.push(SingleLineSpan {
-                line: line_num.into(),
-                start_col: if *line_start > region_start {
+                line: idx.into(),
+                start_col: if line_start > region_start {
                     0
                 } else {
                     region_start - line_start
@@ -99,6 +112,7 @@ impl NewlinePositions {
                 },
             });
         }
+
         res
     }
 
@@ -108,6 +122,8 @@ impl NewlinePositions {
         region_start: usize,
         region_end: usize,
     ) -> Vec<SingleLineSpan> {
+        assert!(region_start <= region_end);
+
         let mut res = vec![];
         for pos in self.from_offsets(region_start, region_end) {
             if pos.line.0 == 0 {
@@ -151,7 +167,7 @@ pub trait MaxLine {
 
 impl<S: AsRef<str>> MaxLine for S {
     fn max_line(&self) -> LineNumber {
-        (max(1, self.as_ref().lines().count()) - 1).into()
+        (max(1, self.as_ref().split('\n').count()) - 1).into()
     }
 }
 
@@ -196,16 +212,16 @@ mod tests {
         assert_eq!(
             line_spans,
             vec![
-                (SingleLineSpan {
+                SingleLineSpan {
                     line: 1.into(),
                     start_col: 1,
                     end_col: 3
-                }),
-                (SingleLineSpan {
+                },
+                SingleLineSpan {
                     line: 2.into(),
                     start_col: 0,
                     end_col: 2
-                })
+                }
             ]
         );
     }
@@ -222,6 +238,12 @@ mod tests {
         assert_eq!(line.max_line().0, 0);
     }
 
+    #[test]
+    fn str_max_line_trailing_newline() {
+        let line: String = "foo\nbar\n".into();
+        assert_eq!(line.max_line().0, 2);
+    }
+
     #[test]
     fn from_offsets_relative_to() {
         let newline_positions: NewlinePositions = "foo\nbar".into();
