@@ -68,7 +68,13 @@ extern "C" {
 }
 
 // TODO: begin/end and object/end.
-const OCAML_ATOM_NODES: [&str; 4] = ["character", "string", "tag", "type_variable"];
+const OCAML_ATOM_NODES: [&str; 5] = [
+    "character",
+    "string",
+    "tag",
+    "type_variable",
+    "attribute_id",
+];
 
 pub fn from_language(language: guess::Language) -> TreeSitterConfig {
     use guess::Language::*;
@@ -143,7 +149,7 @@ pub fn from_language(language: guess::Language) -> TreeSitterConfig {
             TreeSitterConfig {
                 name: "Common Lisp",
                 language: unsafe { tree_sitter_commonlisp() },
-                atom_nodes: (vec!["str_lit"]).into_iter().collect(),
+                atom_nodes: (vec!["str_lit", "char_lit"]).into_iter().collect(),
                 delimiter_tokens: (vec![("(", ")")]),
                 highlight_query: ts::Query::new(language, "").unwrap(),
             }
